<?php
namespace Teknisa\FIS\Modules\Acessorias\Services;

use Teknisa\FIS\Modules\Acessorias\Factories\Fis01900GiaRjFactory;
use Teknisa\FIS\Modules\Acessorias\Services\Fis91000ObrigacoesAcessoriasService;
use Teknisa\FIS\Modules\Acessorias\Services\Agendamento;

use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Libs\Util\NewCode;
use \Teknisa\Libs\Util\Libraries\PHPMailer;

class Fis01900GiaRjService
{
    protected $environment;
    protected $giaRjFactory;
    protected $obrigacoesService;
    
    public $mensagemBody = '';
    public $mensagemBodySucess = '';
    public $mensagemError = '';
    public $mensagemErrorBody = '';
    public $geraArquivo = '';

    public function __construct(Environment $environment, Fis01900GiaRjFactory $giaRjFactory, Fis91000ObrigacoesAcessoriasService $obrigacoesService,
                                    NewCode $newCode, Agendamento $agendamento )
    {
        $this->environment          = $environment;
        $this->giaRjFactory         = $giaRjFactory;
        $this->obrigacoesService    = $obrigacoesService;
        $this->newCode              = $newCode;
        $this->agendamento          = $agendamento;
    }

    /**
     * Função para criar o arquivo da exportação GIA-RJ
     */
    private function createFileGiaRj($row) {
        // Cria os parâmetros para buscar os dados gerados na procedure.
        $params = [
            'NRORG' => $row['NRORG'],
            'NRSEQARQMAG' => $row['NRSEQARQMAG'],
        ];
        $giaRjData = $this->giaRjFactory->getGiaRjData($params);
    
        if(isset($row['NRAGENDAMENTO']) && empty($giaRjData)){
            $this->mensagemError = '<br />'."Não há dados a serem exibidos.";
            return $fileName = false;
        }
        // Chama a função para a criação do arquivo.
        $fileName = $this->obrigacoesService->createFileExportacao($row['NMARQUIVO'], $giaRjData, 'DSREGARQMAG');

        // Retorna o nome do arquivo exportado.
        return $fileName;
    }

    /**
     * Função para a exportação GIA-RJ
     */
    public function exportarGiaRj($row) {
        // Valida os parâmetros associados.
        $this->validateGiaRj($row);
        
        if(isset($row['NRAGENDAMENTO']) && $this->geraArquivo == false){
            return false;
        }
        
        // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
        $row['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($row['NRORG']);

        // Monta o array com os parametros para chamar a procedure
        $params = [
            'CDEMPRESA' => $row['CDEMPRESA'],
            'CDIMPOSTO' => '00',
            'CDINSCESTA'=> $row['CDINSCESTA'],
            'DTINICIAL' => $row['DTINICIAL'],
            'DTFINAL'   => $row['DTFINAL'],
            'MOVOPPR'   => $row['MOVOPPR'],
            'MOVST'     => $row['MOVST'],
            'MOVICMS'   => $row['MOVICMS'],
            'MOVALC'    => $row['MOVALC'],
            'VERSAO'    => $row['VERSAO'],
            'RETIFIC'   => $row['RETIFIC'],
            "NRSEQARQMAG"   => $row["NRSEQARQMAG"],
        ];

        // Chama a procedure de exportação
        $this->giaRjFactory->callGiaRjProcedure($params);

        /**
         * Foi evitado utilizar um bloco finally devido à possível
         * incompativilidade com a versão do PHP
         */
        try
        {
            // Seta os parametros paar a exclusão dos dados temporários
            $params = [
                'NRORG' => $row['NRORG'],
                'NRSEQARQMAG' => $row['NRSEQARQMAG'],
            ];
            // Chama a função para gerar o arquivo texto
            $fileName = $this->createFileGiaRj($row);

            // Exclui os dados temporários da exportação no banco de dados
            $this->giaRjFactory->deleteGiaRjData($params);

            // Retorna o nome do arquivo com suas possíveis modificações
            return $fileName;
        }
        catch(\Exception $e)
        {
            // Exclui os dados temporários da exportaçao no banco de dados
            $this->giaRjFactory->deleteGiaRjData($params);
            throw $e;
        }

    }

    /**
     * Função para validação dos dados informados para o GIA-RJ
     */
    private function validateGiaRj($row) {
        if (isset($row['NRAGENDAMENTO'])){
            
            $this->mensagemError = '';
            
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTREFINI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Referência deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Nome do Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['CDINSCESTA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Incrição Estadual deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Incrição Estadual deve ser informado');
            }
            // Verifica se o campo 'Sem Mov. Ope. Próprias' possui algum vlr informado
            if(empty($row['MOVOPPR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Sem Mov. Ope. Próprias deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Sem Mov. Ope. Próprias deve ser informado');
            }
            // Verifica se o campo 'Sem Mov. Subs. Tributária' possui algum vlr informado
            if(empty($row['MOVST'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Sem Mov. Subs. Tributária deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Sem Mov. Subs. Tributária deve ser informado');
            }
            // Verifica se o campo 'Sem Mov. Outros ICMS' possui algum vlr informado
            if(empty($row['MOVICMS'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Sem Mov. Outros ICMS deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Sem Mov. Outros ICMS deve ser informado');
            }
            // Verifica se o campo 'Sem Mov. ALC/ZFM' possui algum vlr informado
            if(empty($row['MOVALC'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Sem Mov. ALC/ZFM deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Sem Mov. ALC/ZFM deve ser informado');
            }
            // Verifica se o campo 'Versão' possui algum vlr informado
            if(empty($row['VERSAO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Versão deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Versão deve ser informado');
            }
            // Verifica se o campo 'Retificadora' possui algum vlr informado
            if(empty($row['RETIFIC'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Retificadora deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Retificadora deve ser informado');
            }
            
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            //$nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['DTREFINI']);
            $row['DTINICIAL'] = $datas['DTINICIAL'];
            $row['DTFINAL']= $datas['DTFINAL'];
            //$row['NRORG'] = $nrorg;
    
            // Seta o imposto a ser validado no mapa de apuração.
            $impostos = array('00');
    
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
    
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                $this->mensagemError = $this->mensagemError.'<br />'.'Todos os mapas devem estar bloquados para a geração do arquivo.';
                $this->geraArquivo = false;
                //throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
        else {
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTREFINI'])){
                throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Sem Mov. Ope. Próprias' possui algum vlr informado
            if(empty($row['MOVOPPR'])){
                throw new \Exception('Sem Mov. Ope. Próprias deve ser informado');
            }
            // Verifica se o campo 'Sem Mov. Subs. Tributária' possui algum vlr informado
            if(empty($row['MOVST'])){
                throw new \Exception('Sem Mov. Subs. Tributária deve ser informado');
            }
            // Verifica se o campo 'Sem Mov. Outros ICMS' possui algum vlr informado
            if(empty($row['MOVICMS'])){
                throw new \Exception('Sem Mov. Outros ICMS deve ser informado');
            }
            // Verifica se o campo 'Sem Mov. ALC/ZFM' possui algum vlr informado
            if(empty($row['MOVALC'])){
                throw new \Exception('Sem Mov. ALC/ZFM deve ser informado');
            }
            // Verifica se o campo 'Versão' possui algum vlr informado
            if(empty($row['VERSAO'])){
                throw new \Exception('Versão deve ser informada');
            }
            // Verifica se o campo 'Retificadora' possui algum vlr informado
            if(empty($row['RETIFIC'])){
                throw new \Exception('Retificadora deve ser informada');
            }
            
        
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            $nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['DTREFINI']);
            $row['DTINICIAL'] = $datas['DTINICIAL'];
            $row['DTFINAL']= $datas['DTFINAL'];
            $row['NRORG'] = $nrorg;
        
           // Seta o imposto a ser validado no mapa de apuração.
            $impostos = array('00');
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
        
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
    }
    
    
    public function findAgendamento() {
        // Busca os parâmetros conforme empresa e nrorg.
        $agendamento = $this->giaRjFactory->findAgendamento();

        return $agendamento;
    }
    
    public function saveAgendamento($row) {
        try {
            
            $row['CDTELA'] = 'FIS01900';
            
            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtinicial = $dtinicial->format("d/m/Y");
            $dtfinal = $dtfinal->format("d/m/Y");
    
            $row["DTINICIAL"] = $dtinicial;
            $row["DTFINAL"] = $dtfinal;
            
            //var_dump($row);
            //throw new \Exception('ioioioioioi');
            
            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $row["NRAGENDAMENTO"] = $this->newCode->getCodeByTableName('NRAGENDAMENTO', $row["NRORG"], 1, 10);
            }
            
            if($row['CDINSCESTA'] == 'T'){
                $arrayInscEsta = $this->giaRjFactory->getInscEsta($row);
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value['CDINSCESTA'].'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } else if(is_array($row['CDINSCESTA']) == true){
                $arrayInscEsta = $row['CDINSCESTA'];
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value.'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } 
            
            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $this->giaRjFactory->insertAgendamento($row);
            } else {
                $this->giaRjFactory->updateAgendamento($row);
                
                 $arquivos = $this->giaRjFactory->getAgendamentoArquivo($row);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->giaRjFactory->deleteAgendamentoArquivo($arquivo);
                }
                
                $idstatus = 'P';
                $this->giaRjFactory->updateAgendamentoIdStatus($row, $idstatus);
                
            }
            
            $agendamento = $this->giaRjFactory->getAgendamentoInsert($row);
            
            if($agendamento){
                
                $agendamento['NRORG'] = $row['NRORG'];
                $getConfigSMTP = $this->giaRjFactory->getConfiguraSMTP($agendamento)[0];
                if(isset($row['__is_new']) && $row['__is_new'] == true){
                    $nomeJob = $row['CDTELA'].'_'.$row['NRAGENDAMENTO'];
                } else {
                    $nomeJob = $row['CDTELA'].'_'.str_pad($row['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);
                }
                $dataContabAuto = $row['DTAGENDAMENTO'];
                $sequencialJob = $row['NRAGENDAMENTO'];
                $nrorg = $row['NRORG'];
                $descricao = $row['CDTELA'].' - GIA (Rio de Janeiro)'.'. Exportação das declarações Acessórias de forma automática na data de '.$row['DTAGENDAMENTO'];
                //Conferir caminho do diretorio do xampp
                $arqCallService = $getConfigSMTP['CALLSERVPATH'];//'C:\Teknisa\CallService.php';
                //$dirphp = str_replace('/','\',$DIRPHP);
                $dirphp = $getConfigSMTP['DIRPHP'];//'C:/xampp/php';
                $jenkinsPath = $getConfigSMTP['JENKINSPATH'];//'http://192.168.120.132:8080/';
                $execPath = '/execAgendamentoGiaRj';
                $periodicidade = $row['IDPERIAGEN'];
                $jenkinsCreateItem = $getConfigSMTP['JENKCREATITEM'];
                
                $this->agendamento->criaJob($nomeJob, $dataContabAuto, $sequencialJob, $nrorg, $descricao, $arqCallService, $dirphp, $jenkinsPath, $execPath, $periodicidade, $jenkinsCreateItem);
                
            }
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
    }
    
    public function execAgendamento($row){
        try{
            $agendamento = $this->giaRjFactory->findAgendamentoExec($row)[0];
            
            $findParamDeclAcess = $this->giaRjFactory->findParamDeclAcess($agendamento);
            
            $agendamento['MOVOPPR'] = isset($findParamDeclAcess['MOVOPPR']) ? $findParamDeclAcess['MOVOPPR'] : null;
            $agendamento['MOVST']   = isset($findParamDeclAcess['MOVST']) ? $findParamDeclAcess['MOVST'] : null;
            $agendamento['MOVICMS'] = isset($findParamDeclAcess['MOVICMS']) ? $findParamDeclAcess['MOVICMS'] : null;
            $agendamento['MOVALC']  = isset($findParamDeclAcess['MOVALC']) ? $findParamDeclAcess['MOVALC'] : null;
            $agendamento['VERSAO']  = isset($findParamDeclAcess['VERSAO']) ? $findParamDeclAcess['VERSAO'] : null;
            $agendamento['RETIFIC'] = isset($findParamDeclAcess['RETIFIC']) ? $findParamDeclAcess['RETIFIC'] : null;
            
            if($agendamento){
                $this->mensagemBody = '';
                
                $agendamento["NRORG"] = $row['NRORG'];
                
                $agendamento["DTEXECAGEND"] = $agendamento["DTATUAL"];
                
                $agendamento["DTREFINI"] = explode(' ', $agendamento["DTREFINI"])[0];
                
                //Necessário Fazer a verificação
                
                $agendamento['CDINSCESTAARRAY'] = $agendamento['CDINSCESTA'];
                $arrayInscEsta = explode('_',$agendamento['CDINSCESTAARRAY']);
                
                $getConfigSMTP = $this->giaRjFactory->getConfiguraSMTP($agendamento)[0];
                $getContatos = $this->giaRjFactory->getContatos($agendamento);
                
                $mail = new PHPMailer;
                $mail->CharSet = 'UTF-8';
                $mail->isSMTP();                        // Set mailer to use SMTP
                $mail->isHTML();
                $mail->Host = $getConfigSMTP['SERVIDORSMTP'];       // Specify main and backup SMTP servers
                $mail->SMTPAuth = true;                 // Enable SMTP authentication
                $mail->Username = $getConfigSMTP['LOGINSMTP'];    // SMTP username
                $mail->Password = $getConfigSMTP['SENHASMTP'];    // SMTP password
                $mail->From = $getConfigSMTP['LOGINSMTP'];
                $mail->FromName = 'ERP Pebbian';
                $mail->Subject = 'GIA (Rio de Janeiro) de '.$agendamento['DTAGENDAMENTO'];
                // $mail->addAddress($cliente['DSEMAILCLIE']);
                // $mail->addAddress($vendedor['DSEMAILOPER']);
                
                foreach($getContatos as $contato){
                    $mail->addAddress($contato['EMAIL']);
                };
                
                $agendamento["NMEMPRESA"] = $this->giaRjFactory->getNmEmpresa($agendamento)["NMEMPRESA"];
                        
                $this->mensagemBody = 'Caro cliente, '.'<br />'.'<br />';
                $this->mensagemBodySucess = 'Arquivo de GIA (Rio de Janeiro) gerado com Sucesso!'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                $this->mensagemErrorBody = 'Erro ao gerar o arquivo de GIA (Rio de Janeiro):'.'<br />'.'<br />'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                
                
                $contErro = 0;
                $contSucess = 0;
                
                foreach( $arrayInscEsta as $inscEsta ){
                    if(isset($inscEsta) && $inscEsta != ''){
                        
                       $this->geraArquivo = true;
                            
                        $dataName = str_replace('/', '', explode(' ', $agendamento["DTATUAL"])[0]);
                        $horaName = str_replace(':', '', explode(' ', $agendamento["DTATUAL"])[1]);
                        
                        if($agendamento['IDPERIAGEN'] == '0'){
                            $dtinicial = $agendamento["DTINICIAL"];
                            $dtfinal = $agendamento["DTFINAL"];
                        } 
                        else if($agendamento['IDPERIAGEN'] == '1'){
                            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                            $dtinicial = $dtinicial->format("d/m/Y");
                            $dtfinal = $dtfinal->format("d/m/Y");
                        } 
                        else if($agendamento['IDPERIAGEN'] == '2'){
                            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                            $dtinicial = $dtinicial->format("d/m/Y");
                            $dtfinal = $dtfinal->format("d/m/Y");
                        }
                        
                        $agendamento["DTINICIAL"] = $dtinicial;
                        $agendamento["DTFINAL"] = $dtfinal;
                        
                        $agendamento['CDINSCESTA'] = $inscEsta;
                        $agendamento["NMARQUIVO"] = $agendamento['CDTELA'].$agendamento['NRAGENDAMENTO'].'_'.$inscEsta.'_'.$dataName.$horaName;
                          
                        $fileName = $this->exportarGiaRj($agendamento);
                        
                        if($this->mensagemError == ''){
                            $this->mensagemBodySucess = $this->mensagemBodySucess
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA'];
                            ++$contSucess;
                            
                        } else {
                            $this->mensagemErrorBody = $this->mensagemErrorBody
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA']
                            .$this->mensagemError.'<br />'.'<br />';
                            ++$contErro;
                        }
                        
                        if($fileName){
                            $file = sys_get_temp_dir() . DIRECTORY_SEPARATOR . $fileName;
                            $agendamento["NMPATHARQ"] = $file ;
                            
                            $verifArq = $this->giaRjFactory->verAgendamentoArquivo($agendamento);
                            
                            if(empty($verifArq)){
                                $agendamento["NRARQUIVO"] = $this->newCode->getCodeByTableName('NRARQUIVO', $agendamento["NRORG"], 1, 10);
                                $this->giaRjFactory->insertAgendamentoArquivo($agendamento);
                            }
                        }
                
                    }
                }
                
                if(($contErro > 0) && ($contSucess > 0)){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'.'<br />'
                    .'---------------------------------------------------------------------'.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                } 
                else if($contErro > 0){
                    $mail->Body = $this->mensagemBody.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                else if($contSucess > 0){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                
                $idstatus = 'R';
                $this->giaRjFactory->updateAgendamentoIdStatus($agendamento, $idstatus);
                
            }
        
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function deleteAgendamento($row){
        try {    
            
            $agendamento = $this->giaRjFactory->getAgendamentoInsert($row)[0];
            
            
            if($agendamento){
                $nomeJob = $agendamento['CDTELA'].'_'.str_pad($agendamento['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);
                $getConfigSMTP = $this->giaRjFactory->getConfiguraSMTP($agendamento)[0];

                $this->agendamento->apagaJob($nomeJob, null, $getConfigSMTP['JENKINSPATH'], $getConfigSMTP["CALLSERVPATH"]);
            
                $arquivos = $this->giaRjFactory->getAgendamentoArquivo($agendamento);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->giaRjFactory->deleteAgendamentoArquivo($arquivo);
                    $this->giaRjFactory->deleteAgendamento($arquivo);
                    
                } else {
                    $this->giaRjFactory->deleteAgendamento($agendamento);
                }
                
            }
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
                
    }
 
    private function formataData($data) {
        if (!$data) {
            return null;
        }

        // Verifica se está com o formato de data-hora.
        if (strlen($data) == 19) {
            $data = DateUtil::truncateString($data);
        }
        $data = DateUtil::getDataDeString($data);
        $data = DateUtil::truncateData($data);

        return $data;
    }
    
    public function savedeclan($row) {
        try {
            
            $row['CDTELA'] = 'FIS05200';
            $row['CDIMPOSTO'] = '00';
            $array = implode( $row['STIDREGISTRO']);
           // var_dump($array);die;
             $row['STIDREGISTRO'] = $array;
             $data = explode("/", $row['DTREFINI']);
            $row['DTREFINI'] = $data[2];
            //var_dump($row['DTREFINI']);die;
        // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
            $row['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($row['NRORG']);
           
            
            //var_dump($row);
            //throw new \Exception('ioioioioioi');
            
            
              $this->giaRjFactory->savedeclan($row);
            
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
    }
    
    
    public function exportardeclan($row) {
        
        if(isset($row['NRAGENDAMENTO']) && $this->geraArquivo == false){
            return false;
        }
    
        // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
        $row['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($row['NRORG']);
        $row['CDTELA'] = 'FIS05200';
            $row['CDIMPOSTO'] = '00';
             $data = explode("/", $row['DTREFINI']);
            $row['DTREFINI'] = $data[2];
            $array = implode( $row['STIDREGISTRO']);
           // var_dump($array);die;
             $row['STIDREGISTRO'] = $array;
        // Monta o array com os parametros para chamar a procedure
        $params = [
            'CDEMPRESA' => $row['CDEMPRESA'],
            'CDIMPOSTO' => '00',
            'CDINSCESTA'=> $row['CDINSCESTA'],
            'CDLIVROMAG'=> $row['CDLIVROMAG'],
            'VERSAO' => $row['VERSAO'],
            'CONTRIBU'   => $row['CONTRIBU'],
            'DTENCER'   => $row['DTENCER'],
            'DTINICIO'     => $row['DTINICIO'],
            'RETIFICA'   => $row['RETIFICA'],
            'STIDREGISTRO'    => $row['STIDREGISTRO'],
            "NRSEQARQMAG"   => $row["NRSEQARQMAG"],
            'DTREFINI'      => $row['DTREFINI']
        ];

        // Chama a procedure de exportação
        $this->giaRjFactory->exportardeclan($params);

        /**
         * Foi evitado utilizar um bloco finally devido à possível
         * incompativilidade com a versão do PHP
         */
        try
        {
            // Seta os parametros paar a exclusão dos dados temporários
            $params = [
                'NRORG' => $row['NRORG'],
                'NRSEQARQMAG' => $row['NRSEQARQMAG'],
            ];
            // Chama a função para gerar o arquivo texto
            $fileName = $this->createFileGiaRj($row);

            // Retorna o nome do arquivo com suas possíveis modificações
            return $fileName;
        }
        catch(\Exception $e)
        {
            throw $e;
        }

    }
    private function createFiledeclan($row) {
        // Cria os parâmetros para buscar os dados gerados na procedure.
        $params = [
            'NRORG' => $row['NRORG'],
            'NRSEQARQMAG' => $row['NRSEQARQMAG'],
        ];
        $giaRjData = $this->giaRjFactory->getGiaRjData($params);
    
        if(isset($row['NRAGENDAMENTO']) && empty($giaRjData)){
            $this->mensagemError = '<br />'."Não há dados a serem exibidos.";
            return $fileName = false;
        }
        // Chama a função para a criação do arquivo.
        $fileName = $this->obrigacoesService->createFileExportacao($row['NMARQUIVO'], $giaRjData, 'DSREGARQMAG');

        // Retorna o nome do arquivo exportado.
        return $fileName;
    }
    
}